@@ -40,8 +40,18 @@ class Akonadi::CollectionFetchJobPrivate : public JobPrivate
 {
   public:
     CollectionFetchJobPrivate( CollectionFetchJob *parent )
-      : JobPrivate( parent )
+      : JobPrivate( parent ), mBasePrefetch( false )
     {
+
+    }
+
+    void init()
+    {
+      mEmitTimer = new QTimer( q_ptr );
+      mEmitTimer->setSingleShot( true );
+      mEmitTimer->setInterval( 100 );
+      q_ptr->connect( mEmitTimer, SIGNAL( timeout() ), q_ptr, SLOT( timeout() ) );
+      q_ptr->connect( q_ptr, SIGNAL( result( KJob* ) ), q_ptr, SLOT( timeout() ) );
     }
 
     Q_DECLARE_PUBLIC( CollectionFetchJob )
@@ -53,6 +63,8 @@ class Akonadi::CollectionFetchJobPrivate : public JobPrivate
     CollectionFetchScope mScope;
     Collection::List mPendingCollections;
     QTimer *mEmitTimer;
+    bool mBasePrefetch;
+    Collection::List mPrefetchList;
 
     void timeout()
     {
@@ -65,41 +77,64 @@ class Akonadi::CollectionFetchJobPrivate : public JobPrivate
         mPendingCollections.clear();
       }
     }
+
+    void subJobCollectionReceived( const Akonadi::Collection::List &collections )
+    {
+      mPendingCollections += collections;
+      if ( !mEmitTimer->isActive() )
+        mEmitTimer->start();
+    }
+
+    void flushIterativeResult()
+    {
+      Q_Q( CollectionFetchJob );
+
+      if ( mPendingCollections.isEmpty() )
+        return;
+
+      emit q->collectionsReceived( mPendingCollections );
+      mPendingCollections.clear();
+    }
 };
 
 CollectionFetchJob::CollectionFetchJob( const Collection &collection, Type type, QObject *parent )
   : Job( new CollectionFetchJobPrivate( this ), parent )
 {
   Q_D( CollectionFetchJob );
+  d->init();
 
   d->mBase = collection;
   d->mType = type;
-
-  d->mEmitTimer = new QTimer( this );
-  d->mEmitTimer->setSingleShot( true );
-  d->mEmitTimer->setInterval( 100 );
-  connect( d->mEmitTimer, SIGNAL( timeout() ), this, SLOT( timeout() ) );
-  connect( this, SIGNAL( result( KJob* ) ), this, SLOT( timeout() ) );
 }
 
 CollectionFetchJob::CollectionFetchJob( const Collection::List & cols, QObject * parent )
   : Job( new CollectionFetchJobPrivate( this ), parent )
 {
   Q_D( CollectionFetchJob );
+  d->init();
 
   Q_ASSERT( !cols.isEmpty() );
   if ( cols.size() == 1 ) {
     d->mBase = cols.first();
-    d->mType = CollectionFetchJob::Base;
   } else {
     d->mBaseList = cols;
   }
+  d->mType = CollectionFetchJob::Base;
+}
 
-  d->mEmitTimer = new QTimer( this );
-  d->mEmitTimer->setSingleShot( true );
-  d->mEmitTimer->setInterval( 100 );
-  connect( d->mEmitTimer, SIGNAL( timeout() ), this, SLOT( timeout() ) );
-  connect( this, SIGNAL( result( KJob* ) ), this, SLOT( timeout() ) );
+CollectionFetchJob::CollectionFetchJob( const Collection::List & cols, Type type, QObject * parent )
+  : Job( new CollectionFetchJobPrivate( this ), parent )
+{
+  Q_D( CollectionFetchJob );
+  d->init();
+
+  Q_ASSERT( !cols.isEmpty() );
+  if ( cols.size() == 1 ) {
+    d->mBase = cols.first();
+  } else {
+    d->mBaseList = cols;
+  }
+  d->mType = type;
 }
 
 CollectionFetchJob::~CollectionFetchJob()
@@ -118,9 +153,29 @@ void CollectionFetchJob::doStart()
   Q_D( CollectionFetchJob );
 
   if ( !d->mBaseList.isEmpty() ) {
-    foreach ( const Collection &col, d->mBaseList ) {
-      CollectionFetchJob *subJob = new CollectionFetchJob( col, CollectionFetchJob::Base, this );
-      subJob->setFetchScope( fetchScope() );
+    if ( d->mType == Recursive ) {
+      // Because doStart starts several subjobs and @p cols could contain descendants of
+      // other elements in the list, if type is Recusrive, we could end up with duplicates in the result.
+      // To fix this we require an initial fetch of @p cols with Base and RetrieveAncestors,
+      // Iterate over that result removing intersections and then perform the Recursive fetch on
+      // the remainder.
+      d->mBasePrefetch = true;
+      // No need to connect to the collectionsReceived signal here. This job is internal. The
+      // result needs to be filtered through filterDescendants before it is useful.
+      new CollectionFetchJob( d->mBaseList, NonOverlappingRoots, this );
+    } else if ( d->mType == NonOverlappingRoots ) {
+      foreach ( const Collection &col, d->mBaseList ) {
+        // No need to connect to the collectionsReceived signal here. This job is internal. The (aggregated)
+        // result needs to be filtered through filterDescendants before it is useful.
+        CollectionFetchJob *subJob = new CollectionFetchJob( col, Base, this );
+        subJob->fetchScope().setAncestorRetrieval( Akonadi::CollectionFetchScope::All );
+      }
+    } else {
+      foreach ( const Collection &col, d->mBaseList ) {
+        CollectionFetchJob *subJob = new CollectionFetchJob( col, d->mType, this );
+        connect( subJob, SIGNAL(collectionsReceived(Akonadi::Collection::List)), SLOT(subJobCollectionReceived(Akonadi::Collection::List)));
+        subJob->setFetchScope( fetchScope() );
+      }
     }
     return;
   }
@@ -212,6 +267,9 @@ void CollectionFetchJob::doHandleResponse( const QByteArray & tag, const QByteAr
 {
   Q_D( CollectionFetchJob );
 
+  if ( d->mBasePrefetch || d->mType == NonOverlappingRoots )
+    return;
+
   if ( tag == "*" ) {
     Collection collection;
     ProtocolHelper::parseCollection( data, collection );
@@ -235,16 +293,85 @@ void CollectionFetchJob::setResource(const QString & resource)
   d->mScope.setResource( resource );
 }
 
+static Collection::List filterDescendants( const Collection::List &list )
+{
+  Collection::List result;
+
+  QVector<QList<Collection::Id> > ids;
+  foreach( const Collection &collection, list ) {
+    QList<Collection::Id> ancestors;
+    Collection parent = collection.parentCollection();
+    ancestors << parent.id();
+    if ( parent != Collection::root() ) {
+      while ( parent.parentCollection() != Collection::root() ) {
+        parent = parent.parentCollection();
+        QList<Collection::Id>::iterator i = qLowerBound( ancestors.begin(), ancestors.end(), parent.id() );
+        ancestors.insert( i, parent.id() );
+      }
+    }
+    ids << ancestors;
+  }
+
+  QSet<Collection::Id> excludeList;
+  foreach ( const Collection &collection, list ) {
+    int i = 0;
+    foreach( const QList<Collection::Id> &ancestors, ids ) {
+      if ( qBinaryFind( ancestors, collection.id() ) != ancestors.end() ) {
+        excludeList.insert( list.at( i ).id() );
+      }
+      ++i;
+    }
+  }
+
+  foreach ( const Collection &collection, list ) {
+    if ( !excludeList.contains( collection.id() ) )
+      result.append( collection );
+  }
+
+  return result;
+}
+
 void CollectionFetchJob::slotResult(KJob * job)
 {
   Q_D( CollectionFetchJob );
 
-  CollectionFetchJob *list = dynamic_cast<CollectionFetchJob*>( job );
+  CollectionFetchJob *list = qobject_cast<CollectionFetchJob*>( job );
   Q_ASSERT( job );
-  d->mCollections += list->collections();
-  Job::slotResult( job );
-  if ( !job->error() && !hasSubjobs() )
-    emitResult();
+  if ( d->mBasePrefetch ) {
+    d->mBasePrefetch = false;
+    const Collection::List roots = list->collections();
+    Job::slotResult( job );
+    Q_ASSERT( !hasSubjobs() );
+    if ( !job->error() ) {
+      foreach ( const Collection &col, roots ) {
+        CollectionFetchJob *subJob = new CollectionFetchJob( col, d->mType, this );
+        connect( subJob, SIGNAL(collectionsReceived(Akonadi::Collection::List)), SLOT(subJobCollectionReceived(Akonadi::Collection::List)) );
+        subJob->setFetchScope( fetchScope() );
+      }
+    }
+    // No result yet.
+  } else if ( d->mType == NonOverlappingRoots ) {
+    d->mPrefetchList += list->collections();
+    Job::slotResult( job );
+    if ( !job->error() && !hasSubjobs() ) {
+      const Collection::List result = filterDescendants( d->mPrefetchList );
+      d->mPendingCollections += result;
+      d->mCollections = result;
+      d->flushIterativeResult();
+      emitResult();
+    }
+  } else {
+    // We need to tell the subjob to emit its collectionsReceived signal before
+    // the result signal is emitted. That will populate my mPendingCollections
+    // which will be flushed by calling emitResult which will cause
+    // CollectionFetchJobPrivate::timeout to be called.
+    list->d_func()->flushIterativeResult();
+    d->mCollections += list->collections();
+    // Pending collections should have already been emitted by listening to (and flushing) the job.
+    Job::slotResult( job );
+    if ( !job->error() && !hasSubjobs() )
+      emitResult();
+  }
 }
 
 void CollectionFetchJob::includeUnsubscribed(bool include)
