@@ -68,18 +68,19 @@ class CollectionStatisticsDelegatePrivate
     void getCountRecursive( const QModelIndex &index, qint64 &totalCount, qint64 &unreadCount ) const
     {
       Collection collection = qvariant_cast<Collection>( index.data( EntityTreeModel::CollectionRole ) );
-      Q_ASSERT( collection.isValid() );
-      CollectionStatistics statistics = collection.statistics();
-      totalCount += qMax( 0LL, statistics.count() );
-      unreadCount += qMax( 0LL, statistics.unreadCount() );
+      // Do not assert on invalid collections, since a collection may be deleted
+      // in the meantime and deleted collections are invalid.
+      if ( collection.isValid() ) {
+        CollectionStatistics statistics = collection.statistics();
+        totalCount += qMax( 0LL, statistics.count() );
+        unreadCount += qMax( 0LL, statistics.unreadCount() );
 
-      if ( index.model()->hasChildren( index ) )
-      {
-        const int rowCount = index.model()->rowCount( index );
-        for ( int row = 0; row < rowCount; row++ )
-        {
-          static const int column = 0;
-          getCountRecursive( index.model()->index( row, column, index ), totalCount, unreadCount );
+        if ( index.model()->hasChildren( index ) ) {
+          const int rowCount = index.model()->rowCount( index );
+          for ( int row = 0; row < rowCount; row++ ) {
+            static const int column = 0;
+            getCountRecursive( index.model()->index( row, column, index ), totalCount, unreadCount );
+          }
         }
       }
     }
@@ -200,6 +201,7 @@ void CollectionStatisticsDelegate::paint( QPainter *painter,
   Q_D( const CollectionStatisticsDelegate );
   PainterStateSaver stateSaver( painter );
 
+  const QColor textColor = index.data( Qt::ForegroundRole ).value<QColor>();
   // First, paint the basic, but without the text. We remove the text
   // in initStyleOption(), which gets called by QStyledItemDelegate::paint().
   QStyledItemDelegate::paint( painter, option, index );
@@ -223,7 +225,7 @@ void CollectionStatisticsDelegate::paint( QPainter *painter,
   bool expanded = treeView && treeView->isExpanded( firstColumn );
 
   if ( option.state & QStyle::State_Selected ) {
-    painter->setPen( option.palette.highlightedText().color() );
+    painter->setPen( textColor.isValid() ? textColor : option.palette.highlightedText().color() );
   }
 
   Collection collection = index.sibling( index.row(), 0 ).data( EntityTreeModel::CollectionRole ).value<Collection>();
@@ -279,6 +281,8 @@ void CollectionStatisticsDelegate::paint( QPainter *painter,
       QRect unreadRect = textRect;
       folderRect.setRight( textRect.left() + folderWidth );
       unreadRect.setLeft( folderRect.right() );
+      if ( textColor.isValid() )
+        painter->setPen( textColor );
 
       // Draw folder name and unread count
       painter->drawText( folderRect, Qt::AlignLeft | Qt::AlignVCenter, folderName );
