@@ -121,7 +121,7 @@ class CollectionSync::Private
 
       // add already existing children
       if ( localPendingCollections.contains( col.id() ) ) {
-        QList<Collection::Id> childIds = localPendingCollections.take( col.id() );
+        QVector<Collection::Id> childIds = localPendingCollections.take( col.id() );
         foreach ( Collection::Id childId, childIds ) {
           Q_ASSERT( localUidMap.contains( childId ) );
           LocalNode *childNode = localUidMap.value( childId );
@@ -444,6 +444,7 @@ class CollectionSync::Private
     */
     void execute()
     {
+      kDebug() << Q_FUNC_INFO << "localListDone: " << localListDone << " deliveryDone: " << deliveryDone;
       if ( !localListDone )
         return;
 
@@ -503,6 +504,7 @@ class CollectionSync::Private
         return;
       }
 
+      kDebug() << Q_FUNC_INFO << "q->commit()";
       q->commit();
     }
 
@@ -518,7 +520,7 @@ class CollectionSync::Private
     QHash<QString, LocalNode*> localRidMap;
 
     // temporary during build-up of the local node tree, must be empty afterwards
-    QHash<Collection::Id, QList<Collection::Id> > localPendingCollections;
+    QHash<Collection::Id, QVector<Collection::Id> > localPendingCollections;
 
     // removed remote collections in incremental mode
     Collection::List removedRemoteCollections;
@@ -572,6 +574,7 @@ void CollectionSync::doStart()
 {
   CollectionFetchJob *job = new CollectionFetchJob( Collection::root(), CollectionFetchJob::Recursive, this );
   job->fetchScope().setResource( d->resourceId );
+  job->fetchScope().setIncludeUnsubscribed( true );
   job->fetchScope().setAncestorRetrieval( CollectionFetchScope::Parent );
   connect( job, SIGNAL( collectionsReceived( const Akonadi::Collection::List& ) ),
            SLOT( localCollectionsReceived( const Akonadi::Collection::List& ) ) );
