@@ -22,8 +22,10 @@
 #include "contacteditorwidget.h"
 
 #include "addresseditwidget.h"
+#include "categorieseditwidget.h"
 #include "contacteditorpageplugin.h"
 #include "contactmetadata_p.h"
+#include "customfieldseditwidget.h"
 #include "dateeditwidget.h"
 #include "displaynameeditwidget.h"
 #include "emaileditwidget.h"
@@ -63,6 +65,8 @@ class ContactEditorWidget::Private
     void initGuiLocationTab();
     void initGuiBusinessTab();
     void initGuiPersonalTab();
+    void initGuiNotesTab();
+    void initGuiCustomFieldsTab();
 
     void loadCustomPages();
 
@@ -88,6 +92,8 @@ class ContactEditorWidget::Private
     // widgets from phones group
     PhoneEditWidget *mPhonesWidget;
 
+    CategoriesEditWidget *mCategoriesWidget;
+
     // widgets from addresses group
     AddressEditWidget *mAddressesWidget;
 
@@ -117,6 +123,9 @@ class ContactEditorWidget::Private
     // widgets from family group
     KLineEdit *mPartnerWidget;
 
+    // widgets from custom fields group
+    CustomFieldsEditWidget *mCustomFieldsWidget;
+
     // custom editor pages
     QList<Akonadi::ContactEditorPagePlugin*> mCustomPages;
 };
@@ -133,6 +142,8 @@ void ContactEditorWidget::Private::initGui()
   initGuiLocationTab();
   initGuiBusinessTab();
   initGuiPersonalTab();
+  initGuiNotesTab();
+  initGuiCustomFieldsTab();
 
   loadCustomPages();
 }
@@ -140,17 +151,17 @@ void ContactEditorWidget::Private::initGui()
 void ContactEditorWidget::Private::initGuiContactTab()
 {
   QWidget *widget = new QWidget;
-  QVBoxLayout *layout = new QVBoxLayout( widget );
+  QGridLayout *layout = new QGridLayout( widget );
 
-  mTabWidget->addTab( widget, i18n( "Contact" ) );
+  mTabWidget->addTab( widget, i18nc( "@title:tab", "Contact" ) );
 
-  QGroupBox *nameGroupBox = new QGroupBox( i18n( "Name" ) );
-  QGroupBox *internetGroupBox = new QGroupBox( i18n( "Internet" ) );
-  QGroupBox *phonesGroupBox = new QGroupBox( i18n( "Phones" ) );
+  QGroupBox *nameGroupBox = new QGroupBox( i18nc( "@title:group Name related properties of a contact", "Name" ) );
+  QGroupBox *internetGroupBox = new QGroupBox( i18nc( "@title:group", "Internet" ) );
+  QGroupBox *phonesGroupBox = new QGroupBox( i18nc( "@title:group", "Phones" ) );
 
-  layout->addWidget( nameGroupBox );
-  layout->addWidget( internetGroupBox );
-  layout->addWidget( phonesGroupBox );
+  layout->addWidget( nameGroupBox, 0, 0 );
+  layout->addWidget( internetGroupBox, 0, 1 );
+  layout->addWidget( phonesGroupBox, 1, 0, 2, 1 );
 
   QGridLayout *nameLayout = new QGridLayout( nameGroupBox );
   QGridLayout *internetLayout = new QGridLayout( internetGroupBox );
@@ -159,7 +170,7 @@ void ContactEditorWidget::Private::initGuiContactTab()
   QLabel *label = 0;
 
   // setup name group box
-  label = new QLabel( i18n( "Name:" ) );
+  label = new QLabel( i18nc( "@label The name of a contact", "Name:" ) );
   label->setAlignment( Qt::AlignRight | Qt::AlignVCenter );
   nameLayout->addWidget( label, 0, 0 );
 
@@ -171,7 +182,7 @@ void ContactEditorWidget::Private::initGuiContactTab()
   mPhotoWidget->setMinimumSize( QSize( 100, 140 ) );
   nameLayout->addWidget( mPhotoWidget, 0, 2, 4, 1 );
 
-  label = new QLabel( i18n( "Display:" ) );
+  label = new QLabel( i18nc( "@label The display name of a contact", "Display:" ) );
   label->setAlignment( Qt::AlignRight | Qt::AlignVCenter );
   nameLayout->addWidget( label, 1, 0 );
 
@@ -179,7 +190,7 @@ void ContactEditorWidget::Private::initGuiContactTab()
   label->setBuddy( mDisplayNameWidget );
   nameLayout->addWidget( mDisplayNameWidget, 1, 1 );
 
-  label = new QLabel( i18n( "Nickname:" ) );
+  label = new QLabel( i18nc( "@label The nickname of a contact", "Nickname:" ) );
   label->setAlignment( Qt::AlignRight | Qt::AlignVCenter );
   nameLayout->addWidget( label, 2, 0 );
 
@@ -187,7 +198,7 @@ void ContactEditorWidget::Private::initGuiContactTab()
   label->setBuddy( mNickNameWidget );
   nameLayout->addWidget( mNickNameWidget, 2, 1 );
 
-  label = new QLabel( i18n( "Pronunciation:" ) );
+  label = new QLabel( i18nc( "@label The pronunciation of a contact's name", "Pronunciation:" ) );
   label->setAlignment( Qt::AlignRight | Qt::AlignVCenter );
   nameLayout->addWidget( label, 3, 0 );
 
@@ -198,7 +209,7 @@ void ContactEditorWidget::Private::initGuiContactTab()
   nameLayout->setRowStretch( 4, 1 );
 
   // setup Internet group box
-  label = new QLabel( i18n( "Email:" ) );
+  label = new QLabel( i18nc( "@label The email address of a contact", "Email:" ) );
   label->setAlignment( Qt::AlignRight | Qt::AlignVCenter );
   internetLayout->addWidget( label, 0, 0 );
 
@@ -206,7 +217,7 @@ void ContactEditorWidget::Private::initGuiContactTab()
   label->setBuddy( mEmailWidget );
   internetLayout->addWidget( mEmailWidget, 0, 1 );
 
-  label = new QLabel( i18n( "Homepage:" ) );
+  label = new QLabel( i18nc( "@label The homepage URL of a contact", "Homepage:" ) );
   label->setAlignment( Qt::AlignRight | Qt::AlignVCenter );
   internetLayout->addWidget( label, 1, 0 );
 
@@ -214,7 +225,7 @@ void ContactEditorWidget::Private::initGuiContactTab()
   label->setBuddy( mHomepageWidget );
   internetLayout->addWidget( mHomepageWidget, 1, 1 );
 
-  label = new QLabel( i18n( "Blog:" ) );
+  label = new QLabel( i18nc( "@label The blog URL of a contact", "Blog:" ) );
   label->setAlignment( Qt::AlignRight | Qt::AlignVCenter );
   internetLayout->addWidget( label, 2, 0 );
 
@@ -222,7 +233,7 @@ void ContactEditorWidget::Private::initGuiContactTab()
   label->setBuddy( mBlogWidget );
   internetLayout->addWidget( mBlogWidget, 2, 1 );
 
-  label = new QLabel( i18n( "Messaging:" ) );
+  label = new QLabel( i18nc( "@label The instant messaging address of a contact", "Messaging:" ) );
   label->setAlignment( Qt::AlignRight | Qt::AlignVCenter );
   internetLayout->addWidget( label, 3, 0 );
 
@@ -237,17 +248,31 @@ void ContactEditorWidget::Private::initGuiContactTab()
   phonesLayout->addWidget( mPhonesWidget, 0, 0 );
 
   phonesLayout->setRowStretch( 1, 1 );
+
+  // setup categories section
+  QHBoxLayout *categoriesLayout = new QHBoxLayout;
+  label = new QLabel( i18nc( "@label The categories of a contact", "Categories:" ) );
+  label->setAlignment( Qt::AlignRight | Qt::AlignVCenter );
+
+  mCategoriesWidget = new CategoriesEditWidget;
+  label->setBuddy( mCategoriesWidget );
+
+  categoriesLayout->addWidget( label );
+  categoriesLayout->addWidget( mCategoriesWidget );
+
+  layout->addLayout( categoriesLayout, 1, 1 );
+  layout->setRowStretch( 2, 1 );
 }
 
 void ContactEditorWidget::Private::initGuiLocationTab()
 {
   QWidget *widget = new QWidget;
-  QVBoxLayout *layout = new QVBoxLayout( widget );
+  QHBoxLayout *layout = new QHBoxLayout( widget );
 
-  mTabWidget->addTab( widget, i18n( "Location" ) );
+  mTabWidget->addTab( widget, i18nc( "@title:tab", "Location" ) );
 
-  QGroupBox *addressesGroupBox = new QGroupBox( i18n( "Addresses" ) );
-  QGroupBox *coordinatesGroupBox = new QGroupBox( i18n( "Coordinates" ) );
+  QGroupBox *addressesGroupBox = new QGroupBox( i18nc( "@title:group", "Addresses" ) );
+  QGroupBox *coordinatesGroupBox = new QGroupBox( i18nc( "@title:group", "Coordinates" ) );
 
   layout->addWidget( addressesGroupBox );
   layout->addWidget( coordinatesGroupBox );
@@ -272,19 +297,16 @@ void ContactEditorWidget::Private::initGuiBusinessTab()
   QWidget *widget = new QWidget;
   QVBoxLayout *layout = new QVBoxLayout( widget );
 
-  mTabWidget->addTab( widget, i18n( "Business" ) );
+  mTabWidget->addTab( widget, i18nc( "@title:tab", "Business" ) );
 
-  QGroupBox *generalGroupBox = new QGroupBox( i18n( "General" ) );
-  QGroupBox *groupwareGroupBox = new QGroupBox( i18n( "Groupware" ) );
-  QGroupBox *notesGroupBox = new QGroupBox( i18n( "Notes" ) );
+  QGroupBox *generalGroupBox = new QGroupBox( i18nc( "@title:group General properties of a contact", "General" ) );
+  QGroupBox *groupwareGroupBox = new QGroupBox( i18nc( "@title:group", "Groupware" ) );
 
   layout->addWidget( generalGroupBox );
   layout->addWidget( groupwareGroupBox );
-  layout->addWidget( notesGroupBox );
 
   QGridLayout *generalLayout = new QGridLayout( generalGroupBox );
   QGridLayout *groupwareLayout = new QGridLayout( groupwareGroupBox );
-  QGridLayout *notesLayout = new QGridLayout( notesGroupBox );
 
   QLabel *label = 0;
 
@@ -292,7 +314,7 @@ void ContactEditorWidget::Private::initGuiBusinessTab()
   mLogoWidget = new ImageWidget( ImageWidget::Logo );
   generalLayout->addWidget( mLogoWidget, 0, 2, 6, 1, Qt::AlignTop );
 
-  label = new QLabel( i18n( "Organization:" ) );
+  label = new QLabel( i18nc( "@label The organization of a contact", "Organization:" ) );
   label->setAlignment( Qt::AlignRight | Qt::AlignVCenter );
   generalLayout->addWidget( label, 0, 0 );
 
@@ -300,7 +322,7 @@ void ContactEditorWidget::Private::initGuiBusinessTab()
   label->setBuddy( mOrganizationWidget );
   generalLayout->addWidget( mOrganizationWidget, 0, 1 );
 
-  label = new QLabel( i18n( "Profession:" ) );
+  label = new QLabel( i18nc( "@label The profession of a contact", "Profession:" ) );
   label->setAlignment( Qt::AlignRight | Qt::AlignVCenter );
   generalLayout->addWidget( label, 1, 0 );
 
@@ -308,7 +330,7 @@ void ContactEditorWidget::Private::initGuiBusinessTab()
   label->setBuddy( mProfessionWidget );
   generalLayout->addWidget( mProfessionWidget, 1, 1 );
 
-  label = new QLabel( i18n( "Title:" ) );
+  label = new QLabel( i18nc( "@label The title of a contact", "Title:" ) );
   label->setAlignment( Qt::AlignRight | Qt::AlignVCenter );
   generalLayout->addWidget( label, 2, 0 );
 
@@ -316,7 +338,7 @@ void ContactEditorWidget::Private::initGuiBusinessTab()
   label->setBuddy( mTitleWidget );
   generalLayout->addWidget( mTitleWidget , 2, 1 );
 
-  label = new QLabel( i18n( "Department:" ) );
+  label = new QLabel( i18nc( "@label The department of a contact", "Department:" ) );
   label->setAlignment( Qt::AlignRight | Qt::AlignVCenter );
   generalLayout->addWidget( label, 3, 0 );
 
@@ -324,7 +346,7 @@ void ContactEditorWidget::Private::initGuiBusinessTab()
   label->setBuddy( mDepartmentWidget );
   generalLayout->addWidget( mDepartmentWidget, 3, 1 );
 
-  label = new QLabel( i18n( "Office:" ) );
+  label = new QLabel( i18nc( "@label The office of a contact", "Office:" ) );
   label->setAlignment( Qt::AlignRight | Qt::AlignVCenter );
   generalLayout->addWidget( label, 4, 0 );
 
@@ -332,7 +354,7 @@ void ContactEditorWidget::Private::initGuiBusinessTab()
   label->setBuddy( mOfficeWidget );
   generalLayout->addWidget( mOfficeWidget, 4, 1 );
 
-  label = new QLabel( i18n( "Manager's name:" ) );
+  label = new QLabel( i18nc( "@label The manager's name of a contact", "Manager's name:" ) );
   label->setAlignment( Qt::AlignRight | Qt::AlignVCenter );
   generalLayout->addWidget( label, 5, 0 );
 
@@ -340,7 +362,7 @@ void ContactEditorWidget::Private::initGuiBusinessTab()
   label->setBuddy( mManagerWidget );
   generalLayout->addWidget( mManagerWidget, 5, 1 );
 
-  label = new QLabel( i18n( "Assistant's name:" ) );
+  label = new QLabel( i18nc( "@label The assistant's name of a contact", "Assistant's name:" ) );
   label->setAlignment( Qt::AlignRight | Qt::AlignVCenter );
   generalLayout->addWidget( label, 6, 0 );
 
@@ -349,17 +371,14 @@ void ContactEditorWidget::Private::initGuiBusinessTab()
   generalLayout->addWidget( mAssistantWidget, 6, 1 );
 
   // setup groupware group box
-  label = new QLabel( i18n( "Free/Busy:" ) );
+  label = new QLabel( i18nc( "@label The free/busy information of a contact", "Free/Busy:" ) );
   label->setAlignment( Qt::AlignRight | Qt::AlignVCenter );
   groupwareLayout->addWidget( label, 0, 0 );
 
   mFreeBusyWidget = new FreeBusyEditWidget;
   label->setBuddy( mFreeBusyWidget );
   groupwareLayout->addWidget( mFreeBusyWidget, 0, 1 );
-
-  // setup notes group box
-  mNotesWidget = new KTextEdit;
-  notesLayout->addWidget( mNotesWidget, 0, 0 );
+  groupwareLayout->setRowStretch( 1, 1 );
 }
 
 void ContactEditorWidget::Private::initGuiPersonalTab()
@@ -367,10 +386,10 @@ void ContactEditorWidget::Private::initGuiPersonalTab()
   QWidget *widget = new QWidget;
   QVBoxLayout *layout = new QVBoxLayout( widget );
 
-  mTabWidget->addTab( widget, i18n( "Personal" ) );
+  mTabWidget->addTab( widget, i18nc( "@title:tab Personal properties of a contact", "Personal" ) );
 
-  QGroupBox *datesGroupBox = new QGroupBox( i18n( "Dates" ) );
-  QGroupBox *familyGroupBox = new QGroupBox( i18n( "Family" ) );
+  QGroupBox *datesGroupBox = new QGroupBox( i18nc( "@title:group Date related properties of a contact", "Dates" ) );
+  QGroupBox *familyGroupBox = new QGroupBox( i18nc( "@title:group Family related properties of a contact", "Family" ) );
 
   layout->addWidget( datesGroupBox );
   layout->addWidget( familyGroupBox );
@@ -381,7 +400,7 @@ void ContactEditorWidget::Private::initGuiPersonalTab()
   QLabel *label = 0;
 
   // setup dates group box
-  label = new QLabel( i18n( "Birthdate:" ) );
+  label = new QLabel( i18nc( "@label The birthdate of a contact", "Birthdate:" ) );
   label->setAlignment( Qt::AlignRight | Qt::AlignVCenter );
   datesLayout->addWidget( label, 0, 0 );
 
@@ -389,7 +408,7 @@ void ContactEditorWidget::Private::initGuiPersonalTab()
   label->setBuddy( mBirthdateWidget );
   datesLayout->addWidget( mBirthdateWidget, 0, 1 );
 
-  label = new QLabel( i18n( "Anniversary:" ) );
+  label = new QLabel( i18nc( "@label The anniversary of a contact", "Anniversary:" ) );
   label->setAlignment( Qt::AlignRight | Qt::AlignVCenter );
   datesLayout->addWidget( label, 1, 0 );
 
@@ -401,7 +420,7 @@ void ContactEditorWidget::Private::initGuiPersonalTab()
   datesLayout->setColumnStretch( 1, 1 );
 
   // widgets from family group
-  label = new QLabel( i18n( "Partner's name:" ) );
+  label = new QLabel( i18nc( "@label The partner's name of a contact", "Partner's name:" ) );
   label->setAlignment( Qt::AlignRight | Qt::AlignVCenter );
   familyLayout->addWidget( label, 0, 0 );
 
@@ -412,6 +431,28 @@ void ContactEditorWidget::Private::initGuiPersonalTab()
   familyLayout->setRowStretch( 1, 1 );
 }
 
+void ContactEditorWidget::Private::initGuiNotesTab()
+{
+  QWidget *widget = new QWidget;
+  QVBoxLayout *layout = new QVBoxLayout( widget );
+
+  mTabWidget->addTab( widget, i18nc( "@title:tab", "Notes" ) );
+
+  mNotesWidget = new KTextEdit;
+  layout->addWidget( mNotesWidget );
+}
+
+void ContactEditorWidget::Private::initGuiCustomFieldsTab()
+{
+  QWidget *widget = new QWidget;
+  QVBoxLayout *layout = new QVBoxLayout( widget );
+
+  mTabWidget->addTab( widget, i18nc( "@title:tab", "Custom Fields" ) );
+
+  mCustomFieldsWidget = new CustomFieldsEditWidget;
+  layout->addWidget( mCustomFieldsWidget );
+}
+
 void ContactEditorWidget::Private::loadCustomPages()
 {
   qDeleteAll( mCustomPages );
@@ -482,6 +523,9 @@ void ContactEditorWidget::loadContact( const KABC::Addressee &contact, const Ako
   // phones group
   d->mPhonesWidget->loadContact( contact );
 
+  // categories section
+  d->mCategoriesWidget->loadContact( contact );
+
   // address group
   d->mAddressesWidget->loadContact( contact );
 
@@ -514,6 +558,10 @@ void ContactEditorWidget::loadContact( const KABC::Addressee &contact, const Ako
 
   d->mDisplayNameWidget->setDisplayType( (DisplayNameEditWidget::DisplayType)metaData.displayNameMode() );
 
+  // custom fields group
+  d->mCustomFieldsWidget->setLocalCustomFieldDescriptions( metaData.customFieldDescriptions() );
+  d->mCustomFieldsWidget->loadContact( contact );
+
   // custom pages
   foreach ( Akonadi::ContactEditorPagePlugin *plugin, d->mCustomPages )
     plugin->loadContact( contact );
@@ -537,6 +585,9 @@ void ContactEditorWidget::storeContact( KABC::Addressee &contact, Akonadi::Conta
   // phones group
   d->mPhonesWidget->storeContact( contact );
 
+  // categories section
+  d->mCategoriesWidget->storeContact( contact );
+
   // address group
   d->mAddressesWidget->storeContact( contact );
 
@@ -566,6 +617,10 @@ void ContactEditorWidget::storeContact( KABC::Addressee &contact, Akonadi::Conta
   // family group
   d->storeCustom( contact, QLatin1String( "X-SpousesName" ), d->mPartnerWidget->text().trimmed() );
 
+  // custom fields group
+  d->mCustomFieldsWidget->storeContact( contact );
+  metaData.setCustomFieldDescriptions( d->mCustomFieldsWidget->localCustomFieldDescriptions() );
+
   metaData.setDisplayNameMode( d->mDisplayNameWidget->displayType() );
 
   // custom pages
@@ -591,6 +646,9 @@ void ContactEditorWidget::setReadOnly( bool readOnly )
   // widgets from phones group
   d->mPhonesWidget->setReadOnly( readOnly );
 
+  // widgets from categories section
+  d->mCategoriesWidget->setReadOnly( readOnly );
+
   // widgets from addresses group
   d->mAddressesWidget->setReadOnly( readOnly );
 
@@ -620,6 +678,9 @@ void ContactEditorWidget::setReadOnly( bool readOnly )
   // widgets from family group
   d->mPartnerWidget->setReadOnly( readOnly );
 
+  // widgets from custom fields group
+  d->mCustomFieldsWidget->setReadOnly( readOnly );
+
   // custom pages
   foreach ( Akonadi::ContactEditorPagePlugin *plugin, d->mCustomPages )
     plugin->setReadOnly( readOnly );
