@@ -183,7 +183,14 @@ void EntityListView::dragMoveEvent( QDragMoveEvent * event )
 
 void EntityListView::dropEvent( QDropEvent * event )
 {
-  if ( qobject_cast<Akonadi::FavoriteCollectionsModel*>( model() ) || d->mDragDropManager->processDropEvent( event ) ) {
+  bool menuCanceled = false;
+  if ( d->mDragDropManager->processDropEvent( event, menuCanceled ) && !menuCanceled) {
+    if ( menuCanceled )
+      return;
+    QListView::dropEvent( event );
+  }
+  else if ( qobject_cast<Akonadi::FavoriteCollectionsModel*>( model() ) &&!menuCanceled )
+  {
     QListView::dropEvent( event );
   }
 }
@@ -221,4 +228,20 @@ void EntityListView::startDrag( Qt::DropActions supportedActions )
   d->mDragDropManager->startDrag( supportedActions );
 }
 
+void EntityListView::setDropActionMenuEnabled( bool enabled )
+{
+#ifndef QT_NO_DRAGANDDROP
+  d->mDragDropManager->setShowDropActionMenu( enabled );
+#endif
+}
+
+bool EntityListView::isDropActionMenuEnabled() const
+{
+#ifndef QT_NO_DRAGANDDROP
+  return d->mDragDropManager->showDropActionMenu();
+#else
+  return false;
+#endif
+}
+
 #include "entitylistview.moc"
