@@ -355,12 +355,22 @@ class AKONADI_EXPORT EntityTreeModel : public QAbstractItemModel
     };
 
     /**
-     * Describes the state of fetch jobs related to particular entities.
+     * Describes the state of fetch jobs related to particular collections.
+     *
+     * @code
+     *   QModelIndex collectionIndex = getIndex();
+     *   if (collectionIndex.data(EntityTreeModel::FetchStateRole).toLongLong() == FetchingState) {
+     *     // There is a fetch underway
+     *   } else {
+     *     // There is no fetch underway.
+     *   }
+     * @endcode
+     *
      * @since 4.5
      */
     enum FetchState {
-      IdleState,                              ///< There is no fetch in progress.
-      FetchingState                           ///< There is a fetch in progress.
+      IdleState,                              ///< There is no fetch of items in this collection in progress.
+      FetchingState                           ///< There is a fetch of items in this collection in progress.
       // TODO: Change states for reporting of fetching payload parts of items.
     };
 
@@ -612,17 +622,17 @@ private:
     Q_PRIVATE_SLOT( d_func(), void monitoredCollectionStatisticsChanged( Akonadi::Collection::Id,
                                                                          const Akonadi::CollectionStatistics& ) )
 
-    Q_PRIVATE_SLOT( d_func(), void rootCollectionFetched(Akonadi::Collection::List) )
     Q_PRIVATE_SLOT( d_func(), void startFirstListJob() )
     Q_PRIVATE_SLOT( d_func(), void serverStarted() )
 
-    // TODO: Can I merge these into one jobResult slot?
     Q_PRIVATE_SLOT( d_func(), void fetchJobDone( KJob *job ) )
+    Q_PRIVATE_SLOT( d_func(), void rootFetchJobDone( KJob *job ) )
     Q_PRIVATE_SLOT( d_func(), void pasteJobDone( KJob *job ) )
     Q_PRIVATE_SLOT( d_func(), void updateJobDone( KJob *job ) )
     Q_PRIVATE_SLOT( d_func(), void firstFetchJobDone( KJob *job ) )
 
     Q_PRIVATE_SLOT( d_func(), void itemsFetched( Akonadi::Item::List ) )
+    Q_PRIVATE_SLOT( d_func(), void itemsFetched( KJob* ) )
     Q_PRIVATE_SLOT( d_func(), void collectionsFetched( Akonadi::Collection::List ) )
     Q_PRIVATE_SLOT( d_func(), void firstCollectionsFetched( Akonadi::Collection::List ) )
     Q_PRIVATE_SLOT( d_func(), void collectionListFetched( Akonadi::Collection::List ) )
@@ -631,6 +641,7 @@ private:
 
     Q_PRIVATE_SLOT( d_func(), void monitoredMimeTypeChanged( const QString&, bool ) )
     Q_PRIVATE_SLOT( d_func(), void monitoredCollectionsChanged( const Akonadi::Collection&, bool ) )
+    Q_PRIVATE_SLOT( d_func(), void monitoredItemsChanged( const Akonadi::Item&, bool ) )
     Q_PRIVATE_SLOT( d_func(), void monitoredResourcesChanged( const QByteArray&, bool ) )
 
     Q_PRIVATE_SLOT( d_func(), void monitoredCollectionAdded( const Akonadi::Collection&, const Akonadi::Collection& ) )
@@ -652,6 +663,8 @@ private:
     Q_PRIVATE_SLOT( d_func(), void changeFetchState( const Akonadi::Collection & ) )
 
     Q_PRIVATE_SLOT( d_func(), void agentInstanceAdvancedStatusChanged( const QString&, const QVariantMap& ) )
+    Q_PRIVATE_SLOT( d_func(), void agentInstanceRemoved( Akonadi::AgentInstance ) )
+    Q_PRIVATE_SLOT( d_func(), void monitoredItemsRetrieved(KJob* job) )
     //@endcond
 };
 
