@@ -250,7 +250,8 @@ void EntityTreeView::dragMoveEvent( QDragMoveEvent * event )
 void EntityTreeView::dropEvent( QDropEvent * event )
 {
   d->mDragExpandTimer.stop();
-  if ( d->mDragDropManager->processDropEvent( event, ( dropIndicatorPosition () == QAbstractItemView::OnItem ) ) )
+  bool menuCanceled = false;
+  if ( d->mDragDropManager->processDropEvent( event, menuCanceled, ( dropIndicatorPosition () == QAbstractItemView::OnItem ) ) )
     QTreeView::dropEvent( event );
 }
 #endif
