@@ -93,8 +93,17 @@ ErrorOverlay::ErrorOverlay( QWidget *baseWidget, QWidget * parent ) :
   ui->notRunningIcon->setPixmap( KIcon( QLatin1String( "akonadi" ) ).pixmap( 64 ) );
   ui->brokenIcon->setPixmap( KIcon( QString::fromLatin1( "dialog-error" ) ).pixmap( 64 ) );
   ui->progressIcon->setPixmap( KIcon( QLatin1String( "akonadi" ) ).pixmap( 32 ) );
+  ui->quitButton->setText( KStandardGuiItem::quit().text() );
+  ui->detailsQuitButton->setText( KStandardGuiItem::quit().text() );
+
+#ifndef KDEPIM_MOBILE_UI
+  ui->quitButton->hide();
+  ui->detailsQuitButton->hide();
+#endif
 
   connect( ui->startButton, SIGNAL( clicked() ), SLOT( startClicked() ) );
+  connect( ui->quitButton, SIGNAL( clicked() ), SLOT( quitClicked() ) );
+  connect( ui->detailsQuitButton, SIGNAL( clicked() ), SLOT( quitClicked() ) );
   connect( ui->selfTestButton, SIGNAL( clicked() ), SLOT( selfTestClicked() ) );
 
   const ServerManager::State state = ServerManager::state();
@@ -165,6 +174,11 @@ void ErrorOverlay::startClicked()
   ServerManager::start();
 }
 
+void ErrorOverlay::quitClicked()
+{
+  qApp->quit();
+}
+
 void ErrorOverlay::selfTestClicked()
 {
   SelfTestDialog dlg;
