@@ -268,6 +268,9 @@ class StandardActionManager::Private
       if ( actionMenu ) {
         //get rid of the submenus, they are re-created in enableAction. clear() is not enough, doesn't remove the submenu object instances.
         KMenu *menu = actionMenu->menu();
+        //Not necessary to delete and recreate menu when it was not created
+        if ( menu->property( "actionType" ).isValid() && menu->isEmpty() )
+          return;
         delete menu;
         menu = new KMenu();
 
@@ -286,10 +289,11 @@ class StandardActionManager::Private
 
       if ( !menu->isEmpty() )
         return;
-
       const StandardActionManager::Type type = static_cast<StandardActionManager::Type>( menu->property( "actionType" ).toInt() );
 
-      fillFoldersMenu( type,
+      const QSet<QString> mimeTypes = mimeTypesOfSelection( type );
+      fillFoldersMenu( mimeTypes, 
+                       type,
                        menu,
                        collectionSelectionModel->model(),
                        QModelIndex() );
@@ -983,13 +987,11 @@ class StandardActionManager::Private
       return !(CollectionUtils::isStructural( collection ) || isReadOnlyForItems || isReadOnlyForCollections);
     }
 
-    void fillFoldersMenu( StandardActionManager::Type type, QMenu *menu,
+    void fillFoldersMenu( const QSet<QString>& mimeTypes,  StandardActionManager::Type type, QMenu *menu,
                           const QAbstractItemModel *model, QModelIndex parentIndex )
     {
       const int rowCount = model->rowCount( parentIndex );
 
-      const QSet<QString> mimeTypes = mimeTypesOfSelection( type );
-
       for ( int row = 0; row < rowCount; ++row ) {
         const QModelIndex index = model->index( row, 0, parentIndex );
         const Collection collection = model->data( index, CollectionModel::CollectionRole ).value<Collection>();
@@ -1012,7 +1014,7 @@ class StandardActionManager::Private
           popup->setTitle( label );
           popup->setIcon( icon );
 
-          fillFoldersMenu( type, popup, model, index );
+          fillFoldersMenu( mimeTypes, type, popup, model, index );
 
           if ( !readOnly ) {
             popup->addSeparator();
