@@ -19,15 +19,18 @@
 */
 
 #include "addresseedialog.h"
+#ifndef KDEPIM_NO_KRESOURCES
 #include "stdaddressbook.h"
+#endif
 
 #include <kdebug.h>
 #include <klocale.h>
 
+#include <QtCore/QPointer>
+#include <QtCore/QRegExp>
 #include <QtGui/QGroupBox>
 #include <QtGui/QLayout>
 #include <QtGui/QPushButton>
-#include <QtCore/QRegExp>
 
 using namespace KABC;
 
@@ -96,7 +99,9 @@ class AddresseeDialog::Private
 
     QTreeWidget *mSelectedList;
 
+#ifndef KDEPIM_NO_KRESOURCES
     AddressBook *mAddressBook;
+#endif
 
     QHash<QString, QTreeWidgetItem*> mItemDict;
     QHash<QString, QTreeWidgetItem*> mSelectedDict;
@@ -141,7 +146,6 @@ AddresseeDialog::AddresseeDialog( QWidget *parent, bool multiple )
   if ( d->mMultiple ) {
     QBoxLayout *selectedLayout = new QVBoxLayout;
     topLayout->addLayout( selectedLayout );
-    topLayout->setSpacing( spacingHint() );
 
     QGroupBox *selectedGroup =
       new QGroupBox( i18nc( "@title:group selected addressees", "Selected" ), topWidget );
@@ -171,11 +175,13 @@ AddresseeDialog::AddresseeDialog( QWidget *parent, bool multiple )
     setInitialSize( QSize( 650, 350 ) );
   }
 
+#ifndef KDEPIM_NO_KRESOURCES
   d->mAddressBook = StdAddressBook::self( true );
   connect( d->mAddressBook, SIGNAL( addressBookChanged( AddressBook* ) ),
            SLOT( addressBookChanged() ) );
   connect( d->mAddressBook, SIGNAL( loadingFinished( Resource* ) ),
            SLOT( addressBookChanged() ) );
+#endif
 
   d->loadAddressBook();
 }
@@ -193,7 +199,7 @@ Addressee AddresseeDialog::addressee() const
     aItem = dynamic_cast<AddresseeItem *>( d->mSelectedList->topLevelItem( 0 ) );
   } else {
     QList<QTreeWidgetItem*> selected = d->mAddresseeList->selectedItems();
-    if ( selected.count() != 0 ) {
+    if ( !selected.isEmpty() ) {
       aItem = dynamic_cast<AddresseeItem *>( selected.at( 0 ) );
     }
   }
@@ -218,7 +224,7 @@ Addressee::List AddresseeDialog::addressees() const
     }
   } else {
     QList<QTreeWidgetItem*> selected = d->mAddresseeList->selectedItems();
-    if ( selected.count() != 0 ) {
+    if ( !selected.isEmpty() ) {
       aItem = dynamic_cast<AddresseeItem *>( selected.at( 0 ) );
     }
     if ( aItem ) {
@@ -231,22 +237,30 @@ Addressee::List AddresseeDialog::addressees() const
 
 Addressee AddresseeDialog::getAddressee( QWidget *parent )
 {
-  AddresseeDialog dlg( parent );
-  if ( dlg.exec() ) {
-    return dlg.addressee();
+  Addressee contact;
+
+  QPointer<AddresseeDialog> dlg = new AddresseeDialog( parent );
+  if ( dlg->exec() && dlg ) {
+    contact = dlg->addressee();
   }
 
-  return Addressee();
+  delete dlg;
+
+  return contact;
 }
 
 Addressee::List AddresseeDialog::getAddressees( QWidget *parent )
 {
-  AddresseeDialog dlg( parent, true );
-  if ( dlg.exec() ) {
-    return dlg.addressees();
+  Addressee::List contacts;
+
+  QPointer<AddresseeDialog> dlg = new AddresseeDialog( parent, true );
+  if ( dlg->exec() && dlg ) {
+    contacts = dlg->addressees();
   }
 
-  return Addressee::List();
+  delete dlg;
+
+  return contacts;
 }
 
 void AddresseeDialog::Private::loadAddressBook()
@@ -255,12 +269,14 @@ void AddresseeDialog::Private::loadAddressBook()
   mItemDict.clear();
   mAddresseeEdit->completionObject()->clear();
 
+#ifndef KDEPIM_NO_KRESOURCES
   AddressBook::Iterator it;
   for ( it = mAddressBook->begin(); it != mAddressBook->end(); ++it ) {
     AddresseeItem *item = new AddresseeItem( mAddresseeList, (*it) );
     addCompletionItem( (*it).realName(), item );
     addCompletionItem( (*it).preferredEmail(), item );
   }
+#endif
 }
 
 void AddresseeDialog::Private::addCompletionItem( const QString &str, QTreeWidgetItem *item )
@@ -291,7 +307,7 @@ void AddresseeDialog::Private::selectItem( const QString &str )
 void AddresseeDialog::Private::updateEdit()
 {
   QList<QTreeWidgetItem*> selected = mAddresseeList->selectedItems();
-  if ( selected.count() == 0 ) {
+  if ( selected.isEmpty() ) {
     return;
   }
   QTreeWidgetItem *item = selected.at( 0 );
@@ -318,7 +334,7 @@ void AddresseeDialog::Private::addSelected( QTreeWidgetItem *item )
 void AddresseeDialog::Private::removeSelected()
 {
   QList<QTreeWidgetItem*> selected = mSelectedList->selectedItems();
-  if ( selected.count() == 0 ) {
+  if ( selected.isEmpty() ) {
     return;
   }
   AddresseeItem *addrItem = dynamic_cast<AddresseeItem *>( selected.at( 0 ) );
