@@ -3,7 +3,7 @@
 
   Copyright (c) 2004 Reinhold Kainhofer <reinhold@kainhofer.com>
   Copyright (c) 2006-2007 Christian Weilbach <christian_weilbach@web.de>
-  Copyright (c) 2007 Mike Arthur <mike@mikearthur.co.uk>
+  Copyright (c) 2007 Mike McQuaid <mike@mikemcquaid.com>
 
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
@@ -30,24 +30,28 @@
 #include <KDebug>
 #include <KLocale>
 #include <KDateTime>
+#include <kstandarddirs.h>
+
+#include <QtCore/QFile>
+#include <QtCore/QDataStream>
 
 using namespace KBlog;
 
 MetaWeblog::MetaWeblog( const KUrl &server, QObject *parent )
   : Blogger1( server, *new MetaWeblogPrivate, parent )
 {
-  kDebug() << "MetaWeblog()";
+  kDebug();
 }
 
 MetaWeblog::MetaWeblog( const KUrl &server, MetaWeblogPrivate &dd, QObject *parent )
   : Blogger1( server, dd, parent )
 {
-  kDebug() << "MetaWeblog()";
+  kDebug();
 }
 
 MetaWeblog::~MetaWeblog()
 {
-  kDebug() << "~MetaWeblog()";
+  kDebug();
 }
 
 QString MetaWeblog::interfaceName() const
@@ -94,12 +98,14 @@ void MetaWeblog::createMedia( KBlog::BlogMedia *media )
 
 MetaWeblogPrivate::MetaWeblogPrivate()
 {
+  kDebug();
   mCallMediaCounter=1;
+  mCatLoaded=false;
 }
 
 MetaWeblogPrivate::~MetaWeblogPrivate()
 {
-  kDebug() << "~MetaWeblogPrivate()";
+  kDebug();
 }
 
 QList<QVariant> MetaWeblogPrivate::defaultArgs( const QString &id )
@@ -114,14 +120,63 @@ QList<QVariant> MetaWeblogPrivate::defaultArgs( const QString &id )
   return args;
 }
 
+void MetaWeblogPrivate::loadCategories()
+{
+  kDebug();
+
+  if ( mCatLoaded ) {
+    return;
+  }
+  mCatLoaded = true;
+
+  if ( mUrl.isEmpty() || mBlogId.isEmpty() || mUsername.isEmpty() ) {
+    kDebug() << "We need at least url, blogId and the username to create a unique filename.";
+    return;
+  }
+
+  QString filename = "kblog/" + mUrl.host() + '_' + mBlogId + '_' + mUsername;
+  filename = KStandardDirs::locateLocal( "data", filename, true );
+
+  QFile file( filename );
+  if ( !file.open( QIODevice::ReadOnly ) ) {
+    kDebug() << "Cannot open cached categories file: " << filename;
+    return;
+  }
+
+  QDataStream stream( &file );
+  stream >> mCategoriesList;
+  file.close();
+}
+
+void MetaWeblogPrivate::saveCategories()
+{
+  kDebug();
+  if ( mUrl.isEmpty() || mBlogId.isEmpty() || mUsername.isEmpty() ) {
+    kDebug() << "We need at least url, blogId and the username to create a unique filename.";
+    return;
+  }
+
+  QString filename = "kblog/" + mUrl.host() + '_' + mBlogId + '_' + mUsername;
+  filename = KStandardDirs::locateLocal( "data", filename, true );
+
+  QFile file( filename );
+  if ( !file.open( QIODevice::WriteOnly ) ) {
+    kDebug() << "Cannot open cached categories file: " << filename;
+    return;
+  }
+
+  QDataStream stream( &file );
+  stream << mCategoriesList;
+  file.close();
+}
+
+
 void MetaWeblogPrivate::slotListCategories( const QList<QVariant> &result,
                                             const QVariant &id )
 {
   Q_Q( MetaWeblog );
   Q_UNUSED( id );
 
-  QList<QMap<QString,QString> > categoriesList;
-
   kDebug() << "MetaWeblogPrivate::slotListCategories";
   kDebug() << "TOP:" << result[0].typeName();
   if ( result[0].type() != QVariant::Map &&
@@ -149,10 +204,10 @@ void MetaWeblogPrivate::slotListCategories( const QList<QVariant> &result,
         category["rssUrl"] = serverCategory[ "rssUrl" ].toString();
         category["categoryId"] = serverCategory[ "categoryId" ].toString();
         category["parentId"] = serverCategory[ "parentId" ].toString();
-        categoriesList.append( category );
+        mCategoriesList.append( category );
       }
       kDebug() << "Emitting listedCategories";
-      emit q->listedCategories( categoriesList );
+      emit q->listedCategories( mCategoriesList );
     }
   }
   if ( result[0].type() == QVariant::List ) {
@@ -171,11 +226,12 @@ void MetaWeblogPrivate::slotListCategories( const QList<QVariant> &result,
       category["rssUrl"] = serverCategory[ "rssUrl" ].toString();
       category["categoryId"] = serverCategory[ "categoryId" ].toString();
       category["parentId"] = serverCategory[ "parentId" ].toString();
-      categoriesList.append( category );
+      mCategoriesList.append( category );
     }
     kDebug() << "Emitting listedCategories()";
-    emit q->listedCategories( categoriesList );
+    emit q->listedCategories( mCategoriesList );
   }
+  saveCategories();
 }
 
 void MetaWeblogPrivate::slotCreateMedia( const QList<QVariant> &result,
@@ -222,16 +278,17 @@ bool MetaWeblogPrivate::readPostFromMap( BlogPost *post,
   KDateTime dt =
     KDateTime( postInfo["dateCreated"].toDateTime(), KDateTime::UTC );
   if ( dt.isValid() && !dt.isNull() ) {
-    post->setCreationDateTime( dt );
+    post->setCreationDateTime( dt.toLocalZone() );
   }
 
   dt =
     KDateTime( postInfo["lastModified"].toDateTime(), KDateTime::UTC );
   if ( dt.isValid() && !dt.isNull() ) {
-    post->setModificationDateTime( dt );
+    post->setModificationDateTime( dt.toLocalZone() );
   }
 
-  post->setPostId( postInfo["postid"].toString() );
+  post->setPostId( postInfo["postid"].toString().isEmpty() ? postInfo["postId"].toString() :
+                   postInfo["postid"].toString() );
 
   QString title( postInfo["title"].toString() );
   QString description( postInfo["description"].toString() );
@@ -255,8 +312,8 @@ bool MetaWeblogPrivate::readArgsFromPost( QList<QVariant> *args, const BlogPost
   map["categories"] = post.categories();
   map["description"] = post.content();
   map["title"] = post.title();
-  map["lastModified"] = post.modificationDateTime().toUtc().dateTime();
-  map["dateCreated"] = post.creationDateTime().toUtc().dateTime();
+  map["lastModified"] = post.modificationDateTime().dateTime().toUTC();
+  map["dateCreated"] = post.creationDateTime().dateTime().toUTC();
   *args << map;
   *args << QVariant( !post.isPrivate() );
   return true;
