@@ -429,11 +429,6 @@ bool CalendarResources::addIncidence( Incidence *incidence,
   return false;
 }
 
-bool CalendarResources::hasCalendarResources()
-{
-   return d->mDestinationPolicy->hasCalendarResources();
-}
-
 bool CalendarResources::addIncidence( Incidence *incidence )
 {
   clearException();
@@ -621,6 +616,11 @@ Alarm::List CalendarResources::alarms( const KDateTime &from,
   return result;
 }
 
+bool CalendarResources::hasCalendarResources()
+{
+   return d->mDestinationPolicy->hasCalendarResources();
+}
+
 /****************************** PROTECTED METHODS ****************************/
 
 Event::List CalendarResources::rawEventsForDate( const QDate &date,
@@ -634,7 +634,7 @@ Event::List CalendarResources::rawEventsForDate( const QDate &date,
     d->appendIncidences<Event::List>( result,
                                       (*it)->rawEventsForDate( date, timeSpec ), *it );
   }
-  return sortEvents( &result, sortField, sortDirection );
+  return sortEventsForDate( &result, date, timeSpec, sortField, sortDirection );
 }
 
 Event::List CalendarResources::rawEvents( const QDate &start, const QDate &end,
@@ -678,6 +678,11 @@ bool CalendarResources::addJournal( Journal *journal )
   return addIncidence( journal );
 }
 
+bool CalendarResources::addJournal( Journal *journal, ResourceCalendar *resource )
+{
+  return addIncidence( journal, resource );
+}
+
 bool CalendarResources::deleteJournal( Journal *journal )
 {
   bool status;
@@ -706,12 +711,6 @@ void CalendarResources::deleteAllJournals()
   }
 }
 
-bool CalendarResources::addJournal( Journal *journal,
-                                    ResourceCalendar *resource )
-{
-  return addIncidence( journal, resource );
-}
-
 Journal *CalendarResources::journal( const QString &uid )
 {
   CalendarResourceManager::ActiveIterator it;
