@@ -114,7 +114,7 @@ bool ICalFormat::save( const Calendar::Ptr &calendar, const QString &fileName )
 
   KSaveFile file( fileName );
   if ( !file.open() ) {
-    kDebug() << "err:" << file.errorString();
+    kDebug() << "file open error:" << file.errorString();
     setException( new Exception( Exception::SaveErrorOpenFile,
                                  QStringList( fileName ) ) );
 
@@ -126,7 +126,7 @@ bool ICalFormat::save( const Calendar::Ptr &calendar, const QString &fileName )
   file.write( textUtf8.data(), textUtf8.size() );
 
   if ( !file.finalize() ) {
-    kDebug() << "err:" << file.errorString();
+    kDebug() << "file finalize error:" << file.errorString();
     setException( new Exception( Exception::SaveErrorSaveFile,
                                  QStringList( fileName ) ) );
 
@@ -285,7 +285,7 @@ QString ICalFormat::toString( const Calendar::Ptr &cal,
     if ( !tz ) {
       kError() << "bad time zone";
     } else {
-      component = icalcomponent_new_clone( icaltimezone_get_component( tz ) );
+	  component = icalcomponent_new_clone( icaltimezone_get_component( tz ) );
       icalcomponent_add_component( calendar, component );
       icaltimezone_free( tz, 1 );
     }
@@ -311,12 +311,34 @@ QString ICalFormat::toICalString( const Incidence::Ptr &incidence )
 }
 
 QString ICalFormat::toString( const Incidence::Ptr &incidence )
+{
+  return QString::fromUtf8( toRawString( incidence ) );
+}
+
+QByteArray ICalFormat::toRawString( const Incidence::Ptr &incidence )
 {
   icalcomponent *component;
+  ICalTimeZones tzlist;
+  ICalTimeZones tzUsedList;
 
-  component = d->mImpl->writeIncidence( incidence );
+  component = d->mImpl->writeIncidence( incidence, iTIPRequest, &tzlist, &tzUsedList );
 
-  QString text = QString::fromUtf8( icalcomponent_as_ical_string( component ) );
+  QByteArray text = icalcomponent_as_ical_string( component );
+
+  // time zones
+  ICalTimeZones::ZoneMap zones = tzUsedList.zones();
+  for ( ICalTimeZones::ZoneMap::ConstIterator it=zones.constBegin();
+        it != zones.constEnd(); ++it ) {
+    icaltimezone *tz = (*it).icalTimezone();
+    if ( !tz ) {
+      kError() << "bad time zone";
+    } else {
+      icalcomponent *tzcomponent = icaltimezone_get_component( tz );
+      icalcomponent_add_component( component, component );
+      text.append( icalcomponent_as_ical_string( tzcomponent ) );
+      icaltimezone_free( tz, 1 );
+    }
+  }
 
   icalcomponent_free( component );
 
@@ -357,14 +379,34 @@ QString ICalFormat::createScheduleMessage( const IncidenceBase::Ptr &incidence,
 {
   icalcomponent *message = 0;
 
-  // Handle scheduling ID being present
   if ( incidence->type() == Incidence::TypeEvent ||
        incidence->type() == Incidence::TypeTodo ) {
+
     Incidence::Ptr i = incidence.staticCast<Incidence>();
-    if ( i->schedulingID() != i->uid() ) {
-      // We have a separation of scheduling ID and UID
+
+    // Recurring events need timezone information to allow proper calculations
+    // across timezones with different DST.
+    const bool useUtcTimes = !i->recurs();
+
+    const bool hasSchedulingId = (i->schedulingID() != i->uid());
+
+    const bool incidenceNeedChanges = (useUtcTimes || hasSchedulingId);
+
+    if ( incidenceNeedChanges ) {
+      // The incidence need changes, so clone it before we continue
       i = Incidence::Ptr( i->clone() );
-      i->setSchedulingID( QString(), i->schedulingID() );
+
+      // Handle conversion to UTC times
+      if ( useUtcTimes ) {
+        i->shiftTimes( KDateTime::Spec::UTC(), KDateTime::Spec::UTC() );
+      }
+
+      // Handle scheduling ID being present
+      if ( hasSchedulingId ) {
+        // We have a separation of scheduling ID and UID
+        i->setSchedulingID( QString(), i->schedulingID() );
+
+      }
 
       // Build the message with the cloned incidence
       message = d->mImpl->createScheduleComponent( i, method );
