@@ -51,6 +51,14 @@ class KIMAP_EXPORT Session : public QObject
     quint16 port() const;
     State state() const;
 
+    /**
+     * Returns the name that has been set with LoginJob::setUserName()
+     * The user name is useful to uniquely identify an IMAP resource, in combination with the host name
+     * @note If the Session was pre-authenticated, userName() will return an empty string
+     * @since 4.7
+     */
+    QString userName() const;
+
     QByteArray serverGreeting() const;
 
     /**
@@ -85,7 +93,46 @@ class KIMAP_EXPORT Session : public QObject
 
   Q_SIGNALS:
     void jobQueueSizeChanged( int queueSize );
-    void connectionLost();
+
+    /**
+      @deprecated
+      Emitted when we loose a previously established connection
+
+      Likely reasons: server closed the connection, loss of internet connectivity, etc...
+
+      For historical reasons, this signal is also emitted in the event of a failed connection, but
+      you should not rely on this behavior.
+
+      New implementations should use connectionFailed() to detect a failure to connect to the host,
+      and stateChanged() to detect a loss of connectivity.
+    */
+    KDE_DEPRECATED void connectionLost();
+
+    /**
+      Emitted when the Session couldn't connect to the host.
+
+      Likely reasons: invalid host address, no internet connectivity, firewall blocking rules,
+      etc...
+
+      Pending jobs in the queue will be deleted, and the first job in the queue will be failed. (ie:
+      it will have its result signal emitted with a non-zero error code.)
+
+      @since 4.7
+    */
+    void connectionFailed();
+
+    /**
+      Emitted when the session's state changes.
+
+      You can use this signal to detect a connection loss (ie: stateChanged is emitted with newState
+      == KIMAP::Session::Disconnected)
+
+      If you want to receive the stateChanged arguments in your slot, you must register the State
+      enum with @c Q_DECLARE_METATYPE(KIMAP::Session::State) and @c qRegisterMetaType<KIMAP::Session::State>();
+
+      @since 4.7
+    */
+    void stateChanged(KIMAP::Session::State newState, KIMAP::Session::State oldState);
 
   private:
     Q_PRIVATE_SLOT( d, void doStartNext() )
