@@ -166,6 +166,10 @@ bool MBox::load( const QString &fileName )
     if ( d->isMBoxSeparator( line ) ||
          ( d->mMboxFile.atEnd() && ( prevSeparator.size() != 0 ) ) ) {
 
+      // if we are the at the file end, update pos to not forget the last line
+      if ( d->mMboxFile.atEnd() )
+        pos = d->mMboxFile.pos();
+
       // Found the separator or at end of file, the message starts at offs
       quint64 msgSize = pos - offs;
 
@@ -175,17 +179,7 @@ bool MBox::load( const QString &fileName )
         MBoxEntry entry;
         entry.d->mOffset = offs;
         entry.d->mSeparatorSize = prevSeparator.size();
-
-        // There is always a blank line and a separator line between two emails.
-        // Sometimes there are two '\n' characters added to the email (i.e. when
-        // the mail self did not end with a '\n' char) and sometimes only one to
-        // achieve this. When reading the file it is not possible to see which
-        // was the case.
-        if ( d->mMboxFile.atEnd() ) {
-          entry.d->mMessageSize = msgSize; // We use readLine so there's no additional '\n'
-        } else {
-          entry.d->mMessageSize = msgSize - 1;
-        }
+        entry.d->mMessageSize = msgSize - 1;
 
         // Don't add the separator size and the newline up to the message size.
         entry.d->mMessageSize -= prevSeparator.size() + 1;
@@ -450,8 +444,10 @@ QByteArray MBox::readRawMessage( const MBoxEntry &entry )
     }
 
     line = d->mMboxFile.readLine();
-    while ( !d->isMBoxSeparator( line ) && !d->mMboxFile.atEnd() ) {
+    while ( !d->isMBoxSeparator( line ) ) {
       message += line;
+      if ( d->mMboxFile.atEnd() )
+        break;
       line = d->mMboxFile.readLine();
     }
   } else {
