@@ -23,9 +23,8 @@
 #ifndef __KMIME_PARSERS__
 #define __KMIME_PARSERS__
 
-#include<QtCore/QByteArray>
-#include<QtCore/QList>
-#include<QtCore/QRegExp>
+#include<QByteArray>
+#include<QList>
 
 namespace KMime {
 
@@ -104,10 +103,6 @@ class UUEncoded : public NonMimeParser
 
   protected:
     QByteArray s_ubject;
-
-  private:
-    QRegExp m_beginRegExp;
-    QRegExp m_numberRegExp;
 };
 
 /** Helper-class: tries to extract the data from a possibly
