@@ -87,6 +87,18 @@ void TextEditTester::testFormattingUsed()
   QCOMPARE( textEdit.alignment(), Qt::AlignLeft );
   QVERIFY( !textEdit.isFormattingUsed() );
 
+  //
+  // Test layout direction
+  //
+  textEdit.selectAll();
+  QTextCharFormat direction;
+  direction.setLayoutDirection( Qt::RightToLeft );
+  textEdit.mergeCurrentCharFormat( direction );
+  QVERIFY( textEdit.isFormattingUsed() );
+  direction.setLayoutDirection( Qt::LeftToRight );
+  textEdit.mergeCurrentCharFormat( direction );
+  QVERIFY( !textEdit.isFormattingUsed() );
+
   //
   // Test lists
   //
